#!/bin/bash          
echo "*** OECD 308 utility ***"

# command line parameters: [version] [infilename] [outfilename]

MODELVERSION="$1"
INFILENAME="$2"
OUTFILENAME="$3"
POSSIBLEVERSIONS="ABCD"

# echo "ARGS: $1, $2, $3"
VERSIONLENGTH=${#MODELVERSION} 
if [[ $VERSIONLENGTH != 1 ]]
then
	echo "[Error]: model version (1st argument) is not one of A/B/C/D!"
	exit 1
fi
if [[ $POSSIBLEVERSIONS =~ .*$MODELVERSION.* ]]
then
   echo "Using model version $MODELVERSION"
else
	echo "[Error]: model version (1st argument) is not one of A/B/C/D!"
	exit 1
fi
if [[ -z "$INFILENAME" ]] 
then 
	echo "[Error]: input filename (2nd argument) is empty or missing!"
	exit 2
else
	echo "Will read input data from $INFILENAME"
fi
if [[ -z "$OUTFILENAME" ]]
then
	echo "[Error]: output filename (3rd argument) is empty or missing!"
	exit 3
else
	echo "Will write results to $OUTFILENAME"
fi

# check if input file exists
if [ ! -f $INFILENAME ]; then
    echo "[Error]: Input file not found!"
    exit 4
fi

# clone layout file
cp layout.xml layout_spec.xml

# read priors from priors.txt
IFS="="
while read -r name value
do
	sedcmd="sed -i \"\" 's/&$name;/$value/g' layout_spec.xml"
	eval $sedcmd
done < "priors.txt"

sedcmd="sed -i \"\" 's/&modelversion;/$MODELVERSION/g' layout_spec.xml"
eval $sedcmd

sedcmd="sed -i \"\" 's/&inputfilename;/$INFILENAME/g' layout_spec.xml"
eval $sedcmd

# substitutions presumably done at this point

# perform layout test
echo -n ">>> Testing model layout...    "

if ./server layout_spec.xml EVAL > output.log; then
	# do nothing
	:
else
	echo "[Error]: Model layout test failed. Please check output.log for errors."
	exit 5	
fi

echo "Passed"

#perform MCMC
echo ""
echo ">>> Performing MCMC sampling..."
echo "    (This may take up to 20 minutes)"
echo ""

if ./server layout_spec.xml MCMC $OUTFILENAME 20000 10000 > output.log; then
	# do nothing
	:
else
	echo "[Error]: MCMC sampling failed. Please check output.log for errors."
	exit 6	
fi

echo "Finished. Results written to $OUTFILENAME."
